==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/GXMainComponents/SmartyPlugins/function.footer.php <==
<?php
/* --------------------------------------------------------------
   function.footer.php 2018-11-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

require_once __DIR__ . '/function.content_manager.php';

/**
 * @param $params
 * @param $smarty
 *
 * @return mixed|string
 * @throws \Exception
 *
 * @deprecated IMPORTANT! THIS FILE IS DEPRECATED AND WILL BE REPLACED IN THE FUTURE.
 *             MODIFY IT ONLY FOR FIXES. DO NOT APPEND IT WITH NEW FEATURES.
 */
function smarty_function_footer($params, &$smarty)
{
    if (gm_get_conf('SHOW_FOOTER') !== 'true') {
        gm_set_conf('SHOW_FOOTER', 'true');
    }
    
    // render template from content manager
    $footer = MainFactory::create_object('FooterContentView');
    $tpl    = smarty_function_content_manager(['group' => 199], $smarty);
    $tpl    = '{literal}' . $tpl . '{/literal}';
    $footer->set_content_template_from_string($tpl);
    $footer->set_flat_assigns(true);
    $footer->set_('language_id', $_SESSION['languages_id']);
    $footer->set_('customer_status_id', $_SESSION['customers_status']['customers_status_id']);
    $footer->assign_menu_boxes($smarty->tpl_vars);
    $html = $footer->get_html();
    
    // render final template
    $footer->set_template_dir(DIR_FS_CATALOG . StaticGXCoreLoader::getThemeControl()->getThemeHtmlPath());
    $footer->set_flat_assigns(false);
    $template = 'module/footer.html';
    if (StaticGXCoreLoader::getThemeControl()->isThemeSystemActive()) {
        $template = 'layout_footer.html';
    }
    $footer->set_content_template($template);
    $footer->prepare_data();
    $footer->set_content_data('HTML', $html);
    $html = $footer->build_html();
    
    return $html;
}

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GXMainComponents/SmartyPlugins/function.footer.php <==
<?php
/* --------------------------------------------------------------
   function.footer.php 2021-05-04
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2021 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

require_once __DIR__ . '/function.content_manager.php';

/**
 * @param $params
 * @param $smarty
 *
 * @return mixed|string
 * @throws \Exception
 *
 * @deprecated IMPORTANT! THIS FILE IS DEPRECATED AND WILL BE REPLACED IN THE FUTURE.
 *             MODIFY IT ONLY FOR FIXES. DO NOT APPEND IT WITH NEW FEATURES.
 */
function smarty_function_footer($params, &$smarty)
{
    if (gm_get_conf('SHOW_FOOTER') !== 'true') {
        gm_set_conf('SHOW_FOOTER', 'true');
    }
    
    // render template from content manager
    $footer = MainFactory::create_object('FooterThemeContentView');
    $tpl    = smarty_function_content_manager(['group' => 199], $smarty);
    $tpl    = '{literal}' . $tpl . '{/literal}';
    $footer->set_content_template_from_string($tpl);
    $footer->set_flat_assigns(true);
    $footer->set_('language_id', $_SESSION['languages_id']);
    $footer->set_('customer_status_id', $_SESSION['customers_status']['customers_status_id']);
    $footer->assign_menu_boxes($smarty->tpl_vars);
    $html = $footer->get_html();
    
    // render final template
    $footer->set_template_dir(DIR_FS_CATALOG . StaticGXCoreLoader::getThemeControl()->getThemeHtmlPath());
    $footer->set_flat_assigns(false);
    $template = 'layout_footer.html';
    $footer->set_content_template($template);
    $footer->prepare_data();
    $footer->set_content_data('HTML', $html);
    $html = $footer->build_html();
    
    return $html;
}
